@@ -343,10 +343,8 @@ pub fn deep_pull_concat_messy(circuit: CircuitRc, min_size: Option<usize>) -> Ci
 pub fn deep_pull_concat(circuit: CircuitRc, min_size: Option<usize>) -> CircuitRc {
     let mut cache = Default::default();
     let pulled = deep_pull_concat_messy(circuit, min_size);
-    pulled.compiler_print();
     apply_fn_until_same(&pulled, |x: &CircuitRc| {
         let result = deep_push_down_index(compiler_simp(x, &mut cache), min_size);
-        result.compiler_print();
         result
     })
 }
