@@ -137,12 +137,6 @@ pub fn einsum_pull_scatter(einsum: &Einsum) -> Option<CircuitRc> {
 
 #[pyfunction]
 pub fn add_pull_scatter(add: &Add) -> Option<Scatter> {
-    let mut slices: Vec<USlice> = add
-        .info()
-        .shape
-        .iter()
-        .map(|_l| USlice { start: 0, stop: 0 })
-        .collect();
     if !add
         .nodes
         .iter()
@@ -150,6 +144,12 @@ pub fn add_pull_scatter(add: &Add) -> Option<Scatter> {
     {
         return None;
     }
+    let mut slices: Vec<USlice> = add
+        .info()
+        .shape
+        .iter()
+        .map(|_l| USlice { start: 0, stop: 0 })
+        .collect();
     for (operand, rank_difference) in add.nodes_and_rank_differences() {
         let scatter = operand.as_scatter().unwrap();
         for (i, (slice, l)) in
@@ -157,6 +157,11 @@ pub fn add_pull_scatter(add: &Add) -> Option<Scatter> {
         {
             if *l == add.info().shape[i + rank_difference] {
                 slices[i + rank_difference] = slices[i + rank_difference].union(&slice);
+            } else {
+                slices[i + rank_difference] = USlice {
+                    start: 0,
+                    stop: add.info().shape[i + rank_difference],
+                };
             }
         }
     }
